package com.prize.ext.res;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;

import com.prize.theme.db.Tables;

import android.content.Context;
import android.content.pm.PackageManager.NameNotFoundException;
import android.content.res.AssetManager;
import android.database.Cursor;
import android.text.TextUtils;
import android.util.DisplayMetrics;
/***
 * 获取资源辅助类,单例模式
 * @author fanjunchen
 *
 */
public class ResHelper {

	private static volatile ResHelper INSTANCE;
	
	private Context targetCtx;
	
	private Context mCtx;
	
	private String targetPkg;
	
	private HashMap<String, IconBean> mMap = new HashMap<String, IconBean>();
	/**是否正在初始化*/
	private boolean initing = false;
	
	private AssetManager mAssets = null;
	/**锁屏用的context*/
	private Context lockCtx = null;
	/**目标目录*/
	private String targetFolder = "";
	
	private static LockConfigBean lockBean;
	
	private ResHelper(Context ctx) {
		mCtx = ctx;
		initFst();
	}
	
	/***
	 * 初始化图标数据
	 */
	private void initFst() {
		getFolder(mCtx);
		mMap.clear();
		mAssets = null;
		lockCtx = null;
		String[] iconProject = new String[]{Tables.Theme.PKGNAME, Tables._ID};
		Cursor c = mCtx.getContentResolver().query(Tables.Theme.CONTENT_USED_URI, iconProject, null, 
				null, null);
		
		if (c != null) {
			while (c.moveToNext()) {
				String pkgName = c.getString(0);
				changePkg(pkgName);
				break;
			}
			c.close();
		}
		initing = false;
	}
	
	/***
	 * 初始化图标数据
	 */
	private void init() {
		mMap.clear();
		mAssets = null;
		lockCtx = null;
		String[] iconProject = new String[]{Tables.Icons.COMPONENT, Tables.Icons.IMG};
		Cursor c = mCtx.getContentResolver().query(Tables.Icons.CONTENT_MIX_URI, iconProject, null, 
				new String[]{targetPkg}, null);
		
		if (c != null) {
			while (c.moveToNext()) {
				IconBean b = new IconBean();
				b.name = c.getString(1);
				String cmp = c.getString(0);
				if (cmp != null) {
					String[] strs = cmp.split("/");
					if (strs.length > 1)
						cmp = strs[1];
				}
				mMap.put(cmp, b);
			}
			
			c.close();
		}
		initing = false;
		
		initLockConfig();
	}
	/***
	 * 获取对象
	 * @param ctx
	 * @return
	 */
	public static ResHelper getInstance(Context ctx) {
		if (null == INSTANCE) {
			synchronized(ResHelper.class) {
				if (null == INSTANCE)
					INSTANCE = new ResHelper(ctx);
			}
		}
		return INSTANCE;
	}
	
	/***
	 * create other pkg Context to fetch Resources.
	 * @param pkgName
	 */
	private void createContext(String pkgName) {
		if (targetCtx != null && targetPkg != null && targetPkg.equals(pkgName))
			return;
		try {
			targetPkg = pkgName;
			initing = true;
			init();
			targetCtx = mCtx.createPackageContext(pkgName, Context.CONTEXT_INCLUDE_CODE
					| Context.CONTEXT_IGNORE_SECURITY);
		} catch (NameNotFoundException e) {
			e.printStackTrace();
			targetCtx = null;
		}
	}
	/***
	 * 设置目录上下文
	 */
	public void setTargetCtx(Context ctx) {
		targetPkg = ctx.getPackageName();
		initing = true;
		init();
		targetCtx = ctx;
	}
	/***
	 * change other context;接收到相应的事件通知如广播 后应该调用此方法来改变当前的环境
	 * @param pkgName
	 */
	public void changePkg(String pkgName) {
		createContext(pkgName);
	}
	/***
	 * 获取app icon图标流，<b>用完后请即时关闭此流</b>
	 * @param cmp
	 * @return InputStream
	 */
	public InputStream getAppIconStream(String cmp) {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		IconBean b = mMap.get(cmp);
		if (b != null && b.type <2) {
			try {
				String path = targetFolder + "icon/" + b.name;
				if (null == mAssets)
					mAssets = targetCtx.getAssets();
	            is = mAssets.open(path);
	        } catch (IOException e) {
	        	is = null;
	        	b.type = 2;
	            e.printStackTrace();
	        }
		}
		return is;
	}
	/***
	 * 获取某主题缩略图
	 * @param pkgName
	 * @param thumbName
	 * @return
	 */
	public InputStream getThemeThumb(String pkgName, String thumbName) {
		
		if (TextUtils.isEmpty(pkgName))
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "preview/" + thumbName;
			
			Context ctx = null;
			if (pkgName.equals(mCtx.getPackageName())) {
				ctx = mCtx;
			}
			else 
				ctx = mCtx.createPackageContext(pkgName, Context.CONTEXT_INCLUDE_CODE
					| Context.CONTEXT_IGNORE_SECURITY);
			AssetManager assets = ctx.getAssets();
            is = assets.open(path);
            
            if (ctx != mCtx)
            	ctx = null;
        } catch (Exception e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	/***
	 * 获取桌面资源 icon图标流，<b>用完后请即时关闭此流</b>
	 * @param cmp
	 * @return InputStream
	 */
	public InputStream getPatchIconStream(String name) {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "patch_icon/" + name;
			if (null == mAssets)
				mAssets = targetCtx.getAssets();
            is = mAssets.open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	
	/***
	 * 获取预览图片流，<b>用完后请即时关闭此流</b>
	 * @param cmp
	 * @return InputStream
	 */
	public InputStream getPreviewStream(String name) {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "preview/" + name;
			if (null == mAssets)
				mAssets = targetCtx.getAssets();
            is = mAssets.open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	
	/***
	 * 获取文件夹背景图片流，<b>用完后请即时关闭此流</b>
	 * @return InputStream
	 */
	public InputStream getFolderBgStream() {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "folder/folder_bg.png";
			if (null == mAssets)
				mAssets = targetCtx.getAssets();
            is = mAssets.open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	
	/***
	 * 获取应用图标背景图片流，<b>用完后请即时关闭此流</b>
	 * @param index 序号，从0开始
	 * @return InputStream
	 */
	public InputStream getIconBgStream(int index) {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "iconbg/icon_" + index + ".png";
			if (null == mAssets)
				mAssets = targetCtx.getAssets();
            is = mAssets.open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	
	/***
	 * 获取应用图标背景图片流，<b>用完后请即时关闭此流</b>
	 * @return InputStream
	 */
	public InputStream getIconBgStream() {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "iconbg/icon_bg.png";
			if (null == mAssets)
				mAssets = targetCtx.getAssets();
            is = mAssets.open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	
	/***
	 * 获取icon Mask图片流，<b>用完后请即时关闭此流</b>
	 * @return InputStream
	 */
	public InputStream getIconMaskBgStream() {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "iconbg/mask.png";
			if (null == mAssets)
				mAssets = targetCtx.getAssets();
            is = mAssets.open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	
	/***
	 * 获取锁屏背景图片流，<b>用完后请即时关闭此流</b>
	 * @return InputStream
	 */
	public InputStream getLockScreenStream() {
		if (null == lockCtx) {
			String[] lockProject = new String[]{Tables.LockImg.PKGNAME, Tables.LockImg.THEME_ID};
			Cursor c = mCtx.getContentResolver().query(Tables.LockImg.CONTENT_USED_URI, lockProject, null, 
					null, null);
			if (c != null) {
				if (c.moveToFirst()) {
					String lockPkg = c.getString(0);
					try {
						lockCtx = mCtx.createPackageContext(lockPkg, Context.CONTEXT_INCLUDE_CODE
								| Context.CONTEXT_IGNORE_SECURITY);
					} catch (NameNotFoundException e) {
						e.printStackTrace();
					}
				}
				c.close();
			}
		}
		else {
			String[] lockProject = new String[]{Tables.LockImg.PKGNAME, Tables.LockImg.THEME_ID};
			Cursor c = mCtx.getContentResolver().query(Tables.LockImg.CONTENT_USED_URI, lockProject, null, 
					null, null);
			if (c != null) {
				if (c.moveToFirst()) {
					String lockPkg = c.getString(0);
					if (!lockCtx.getPackageName().equals(lockPkg)) {
						try {
							lockCtx = mCtx.createPackageContext(lockPkg, Context.CONTEXT_INCLUDE_CODE
									| Context.CONTEXT_IGNORE_SECURITY);
						} catch (NameNotFoundException e) {
							e.printStackTrace();
						}
					}
				}
				c.close();
			}
			
		}
		
		if (null == lockCtx)
			return null;
		
		InputStream is = null;
		try {
			String path = targetFolder + "lockscr/lockscr.jpg";
            is = lockCtx.getAssets().open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	
	/***
	 * 获取当前正在使用的主题壁纸图片流，<b>用完后请即时关闭此流</b>
	 * @return InputStream
	 */
	public InputStream getWallpaperStream() {
		if (null == targetCtx)
			return null;
		InputStream is = null;
		try {
			String path = targetFolder + "wallpaper/wall.jpg";
			if (null == mAssets)
				mAssets = targetCtx.getAssets();
            is = mAssets.open(path);
        } catch (IOException e) {
        	is = null;
            e.printStackTrace();
        }
		return is;
	}
	/***
	 * 取目录
	 * @param ctx
	 * @return
	 */
	private String getFolder(Context ctx) {
		DisplayMetrics metric = ctx.getResources().getDisplayMetrics();
		int a = metric.densityDpi;
		// 忽略ldpi与mdpi， 小于280为hdpi, 大于等于280且小于等于360为xhdpi, 大于360的为xxhdpi
		if (a < 280) {
			targetFolder = "drawable-hdpi" + File.separator;
		}
		else if (a >= 280 && a <= 360) {
			targetFolder = "drawable-xhdpi" + File.separator;
		}
		else  {//(a > 360)
			targetFolder = "drawable-xxhdpi" + File.separator;
		}
		metric = null;
		return targetFolder;
	}
	/***
	 * 获取锁屏配置
	 * @return
	 */
	public LockConfigBean getLockConfig() {
		
		if (null == lockBean)
			initLockConfig();
		
		return lockBean;
	}
	/***
	 * 获取锁屏配置
	 * @return
	 */
	private void initLockConfig() {
		
		lockBean = null;
		Cursor c = mCtx.getContentResolver().query(Tables.LockScrConfig.CONTENT_USED_URI, null, null, 
				null, null);
		if (c != null) {
			if (c.moveToFirst()) {
				lockBean = new LockConfigBean();
				lockBean.dateColor = c.getString(c.getColumnIndex(Tables.LockScrConfig.DATE_COLOR));
				lockBean.dateSz = c.getInt(c.getColumnIndex(Tables.LockScrConfig.DATE_SZ));
				lockBean.timeColor = c.getString(c.getColumnIndex(Tables.LockScrConfig.TIME_COLOR));
				lockBean.timeSz = c.getInt(c.getColumnIndex(Tables.LockScrConfig.TIME_SZ));
				
				lockBean.timeX = c.getInt(c.getColumnIndex(Tables.LockScrConfig.TIME_X));
				lockBean.timeY = c.getInt(c.getColumnIndex(Tables.LockScrConfig.TIME_Y));
				
				lockBean.dateX = c.getInt(c.getColumnIndex(Tables.LockScrConfig.DATE_X));
				lockBean.dateY = c.getInt(c.getColumnIndex(Tables.LockScrConfig.DATE_Y));
				
				lockBean.hint = c.getString(c.getColumnIndex(Tables.LockScrConfig.HINT));
				
				lockBean.direct = c.getInt(c.getColumnIndex(Tables.LockScrConfig.DIRECT));
				lockBean.lockType = c.getInt(c.getColumnIndex(Tables.LockScrConfig.LOCK_TYPE));
				
				lockBean.pkgName = c.getString(c.getColumnIndex(Tables.LockScrConfig.PKGNAME));
			}
			c.close();
		}
	}
	/***
	 * 当某个主题卸载时调用
	 */
	public void changeLockConfig(String pkgName) {
		if (lockBean != null && pkgName.equals(lockBean.pkgName))
			lockBean = null;
	}
}
