package com.prize.theme.db;

import android.net.Uri;
/***
 * 表及对外常量定义
 * @author fanjunchen
 *
 */
public class Tables {

	/**安装成功并解析成功即此主题包可用**/
	public static final String BRD_ACTION_INSTALLED = "theme_install_and_parse_success";
	/**卸载主题包并删除成功**/
	public static final String BRD_ACTION_UNINSTALL_DEL = "theme_uninstall_and_del_success";
	/**安装的主题包不符合要求即不作为主题包使用**/
	public static final String BRD_ACTION_PARSE_FAIL = "theme_installed_not_adapter_apk";
	/**应用某主题广播**/
	public static final String BRD_ACTION_APPLY_THEME = "theme_applied_notification";
	/**应用某锁屏广播**/
	public static final String BRD_ACTION_APPLY_LOCK = "lockscr_applied_notification";
	/**应用某壁纸广播**/
	public static final String BRD_ACTION_APPLY_WALL = "lockscr_applied_wallpaper";
	/**告诉桌面已经进入美化中心，可以截图了**/
	public static final String BRD_ACTION_HOME_SHOT = "home_page_screen_shot_action";
	/**应用某主题广播带的参数 (包名)**/
	public static final String BRD_EXTRA = "pkg_name";
	/**参数类型， 暂定给锁屏用 1表示另一个参数为包名， 2表示另一个参数为文件路径； 若是壁纸或主题的话表示 0表示固定壁纸, 1表示滑动壁纸**/
	public static final String BRD_EXTRA_TYPE = "p_type";
	/**桌面页切图存储的文件名称*/
	public static final String DESK_PAGE_IMG = "desk/imgPreview.png";
	/**主键ID*/
	public static final String _ID = "_id";
	/**Authority*/
	public static final String AUTHORITY = "com.android.pthemes";
	/**Authority uri*/
	public static final Uri AUTHORITY_URI = Uri.parse("content://" + AUTHORITY);
	/***
	 * 主题表
	 * @author fanjunchen
	 *
	 */
	public static class Theme {
		public static final Uri CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "themes");
		/**获取当前使用的主题包*/
		public static final Uri CONTENT_USED_URI = Uri.withAppendedPath(AUTHORITY_URI, "themesUsed");
		/**查询某主题*/
		public static final Uri QUERY_CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "themes/lookup");
		/**表名*/
		public static final String T_NAME = "theme";
		/**名称*/
		public static final String NAME = "_name";
		/**包名*/
		public static final String PKGNAME = "pkgName";
		/**状态  0未下载， 1下载中，2已下载，4已安装,5使用中*/
		public static final String STATUS = "status";
		/**作者 */
		public static final String AUTHOR = "_author";
		/**简介*/
		public static final String DISC = "_discrib";
		/**包大小*/
		public static final String AMOUNT = "_amount";
		/**最后修改时间*/
		public static final String UPDATE_TIME = "update_time";
		/**创建时间*/
		public static final String CREATE_TIME = "create_time";
		/**主题开发时间*/
		public static final String DEV_TIME = "dev_time";
		/**主题类型*/
		public static final String TYPE = "type";
		/**主题反馈邮箱*/
		public static final String AUTHOR_EMAIL = "email";
		/**主题缩略图*/
		public static final String THUMB = "_thumb";
		/**版本号*/
		public static final String VERSION = "_version";
		/**
		 * 创建语句
		 * @return
		 */
		public static String createSQL() {
			StringBuilder sb = new StringBuilder();
			sb.append("CREATE TABLE " + T_NAME + " (")
              .append(_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, ")
              .append(NAME + " TEXT,")
              .append(PKGNAME + " TEXT,")
              .append(STATUS + " INTEGER DEFAULT 0,")
              .append(AUTHOR + " TEXT,")
              .append(DISC + " TEXT,")
              .append(AMOUNT + " INTEGER DEFAULT 0,")
              .append(UPDATE_TIME + " INTEGER,")
              .append(CREATE_TIME + " INTEGER,")
              .append(DEV_TIME + " TEXT,")
              .append(TYPE + " TEXT,")
              .append(AUTHOR_EMAIL + " TEXT,")
              .append(VERSION + " TEXT,")
              .append(THUMB + " TEXT")
              .append(')');
			
			String str = sb.toString();
			sb = null;
			return str;
		}
		/**
		 * 删除表语句
		 * @return
		 */
		public static String dropSQL() {
			return "DROP TABLE IF EXISTS " + T_NAME;
		}
	}
	/*** 主题表 Provider查询时返回的列     */
    public static final String[] ThemeProjection = {
        Tables._ID,
        Tables.Theme.NAME,
        Tables.Theme.PKGNAME,
        Tables.Theme.AUTHOR,
        Tables.Theme.AMOUNT,
        Tables.Theme.DISC,
        Tables.Theme.VERSION
	};
    
	/***
	 * 主题图标资源表
	 * @author fanjunchen
	 *
	 */
	public static class Icons {
		public static final Uri CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "icons");
		/**联合查询，查询某主题下的appicon， 包名为第一个参数（whereArgs）*/
		public static final Uri CONTENT_MIX_URI = Uri.withAppendedPath(AUTHORITY_URI, "iconsmix");
		/**表名*/
		public static final String T_NAME = "icons";
		/**组件名称*/
		public static final String COMPONENT = "comp";
		/**对应的图标名称 全称即带扩展名 eg:a.png*/
		public static final String IMG = "imgName";
		/**主题ID*/
		public static final String THEME_ID = "themeId";
		/**
		 * 创建语句
		 * @return
		 */
		public static String createSQL() {
			StringBuilder sb = new StringBuilder();
			sb.append("CREATE TABLE " + T_NAME + " (")
              .append(_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, ")
              .append(COMPONENT + " TEXT,")
              .append(IMG + " TEXT,")
              .append(THEME_ID + " INTEGER")
              .append(')');
			
			String str = sb.toString();
			sb = null;
			return str;
		}
		/**
		 * 删除表语句
		 * @return
		 */
		public static String dropSQL() {
			return "DROP TABLE IF EXISTS " + T_NAME;
		}
	}
	
	/*** 图标表Provider查询时返回的列     */
    public static final String[] IconProjection = {
        _ID,
        Icons.COMPONENT,
        Icons.IMG,
        Icons.THEME_ID,
	};
	
	/***
	 * 主题预览图 表
	 * @author fanjunchen
	 *
	 */
	public static class Preview {
		public static final Uri CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "previews");
		/**联合查询，查询某主题下的preview， 包名为第一个参数（whereArgs）*/
		public static final Uri CONTENT_MIX_URI = Uri.withAppendedPath(AUTHORITY_URI, "previewsmix");
		/**表名*/
		public static final String T_NAME = "desk_preview";
		/**对应的图片名称 全称即带扩展名 eg:1.jpg*/
		public static final String IMG = "imgName";
		/**排序号*/
		public static final String SORT = "_sort";
		/**主题ID*/
		public static final String THEME_ID = "themeId";
		/**
		 * 创建语句
		 * @return
		 */
		public static String createSQL() {
			StringBuilder sb = new StringBuilder();
			sb.append("CREATE TABLE " + T_NAME + " (")
              .append(_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, ")
              .append(IMG + " TEXT,")
              .append(SORT + " INTEGER DEFAULT 9,")
              .append(THEME_ID + " INTEGER")
              .append(')');
			
			String str = sb.toString();
			sb = null;
			return str;
		}
		/**
		 * 删除表语句
		 * @return
		 */
		public static String dropSQL() {
			return "DROP TABLE IF EXISTS " + T_NAME;
		}
	}
	
	/*** 主题预览图片表Provider查询时返回的列     */
    public static final String[] PreviewProjection = {
        _ID,
        Preview.SORT,
        Preview.IMG,
        Preview.THEME_ID,
	};
	/***
	 * 主题配制 表
	 * @author fanjunchen
	 *
	 */
	public static class Config {
		public static final Uri CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "config");
		/**联合查询，查询某主题下的配置项， 包名为第一个参数（whereArgs）*/
		public static final Uri CONTENT_MIX_URI = Uri.withAppendedPath(AUTHORITY_URI, "configmix");
		/**表名*/
		public static final String T_NAME = "config";
		/**对应的键*/
		public static final String KEY = "_key";
		/**对应的键值*/
		public static final String VALUE = "_val";
		/**对应键值的类型*/
		public static final String TYPE = "_type";
		/**说明 */
		public static final String DISC = "discrib";
		/**主题ID*/
		public static final String THEME_ID = "themeId";
		/**
		 * 创建语句
		 * @return
		 */
		public static String createSQL() {
			StringBuilder sb = new StringBuilder();
			sb.append("CREATE TABLE " + T_NAME + " (")
              .append(_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, ")
              .append(KEY + " TEXT,")
              .append(VALUE + " TEXT,")
              .append(TYPE + " TEXT,")
              .append(DISC + " TEXT,")
              .append(THEME_ID + " INTEGER")
              .append(')');
			
			String str = sb.toString();
			sb = null;
			return str;
		}
		/**
		 * 删除表语句
		 * @return
		 */
		public static String dropSQL() {
			return "DROP TABLE IF EXISTS " + T_NAME;
		}
	}
	
	/*** 主题预览图片表Provider查询时返回的列     */
    public static final String[] ConfigProjection = {
        _ID,
        Config.KEY,
        Config.VALUE,
        Config.TYPE,
        Config.THEME_ID,
	};
    
    /***
	 * 锁屏壁纸表
	 * @author fanjunchen
	 *
	 */
	public static class LockImg {
		public static final Uri CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "lockscr");
		/**获取当前使用的主题包*/
		public static final Uri CONTENT_USED_URI = Uri.withAppendedPath(AUTHORITY_URI, "lockscrUsed");
		/**表名*/
		public static final String T_NAME = "lockimg";
		/**包名，若没有包名则就是网络的*/
		public static final String PKGNAME = "pkgName";
		/**名称*/
		public static final String NAME = "_name";
		/**主题ID*/
		public static final String THEME_ID = "themeId";
		/**状态  0未下载， 1 下载中， 2已下载，3使用中*/
		public static final String STATUS = "status";
		/**锁屏缩略图名称或URL*/
		public static final String THUMB = "_thumb";
		/**锁屏原图名称或URL*/
		public static final String RAWIMG = "rawImg";
		/**
		 * 创建语句
		 * @return
		 */
		public static String createSQL() {
			StringBuilder sb = new StringBuilder();
			sb.append("CREATE TABLE " + T_NAME + " (")
              .append(_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, ")
              .append(PKGNAME + " TEXT,")
              .append(NAME + " TEXT,")
              .append(THEME_ID + " INTEGER,")
              .append(STATUS + " INTEGER DEFAULT 0,")
              .append(THUMB + " TEXT,")
              .append(RAWIMG + " TEXT")
              .append(')');
			
			String str = sb.toString();
			sb = null;
			return str;
		}
		/**
		 * 删除表语句
		 * @return
		 */
		public static String dropSQL() {
			return "DROP TABLE IF EXISTS " + T_NAME;
		}
	}
	
	/*** 锁屏表Provider查询时返回的列     */
    public static final String[] LockProjection = {
        _ID,
        LockImg.PKGNAME,
        LockImg.NAME,
        LockImg.STATUS,
        LockImg.THEME_ID,
        LockImg.THUMB,
        LockImg.RAWIMG
	};
    
    /***
	 * 锁屏配置表
	 * @author fanjunchen
	 *
	 */
	public static class LockScrConfig {
		
		public static final Uri CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "lockconfig");
		/**获取当前使用的锁屏配置*/
		public static final Uri CONTENT_USED_URI = Uri.withAppendedPath(AUTHORITY_URI, "lockconfigUsed");
		/**表名*/
		public static final String T_NAME = "lockconfig";
		/**包名，若没有包名则就是网络的*/
		public static final String PKGNAME = "pkgName";
		/**名称*/
		public static final String NAME = "_name";
		/**状态  0未下载， 1 下载中， 2已下载，3使用中*/
		public static final String STATUS = "status";
		/**锁屏类型*/
		public static final String LOCK_TYPE = "lockType";
		/**滑动方向*/
		public static final String DIRECT = "_direct";
		/**滑动提示文字*/
		public static final String HINT = "_hint";
		/**时间颜色*/
		public static final String TIME_COLOR = "timeColor";
		/**时间字体大小*/
		public static final String TIME_SZ = "timeSz";
		/**时间x方向起始位置*/
		public static final String TIME_X = "tX";
		/**时间y方向起始位置*/
		public static final String TIME_Y = "tY";
		
		/**日期颜色*/
		public static final String DATE_COLOR = "dateColor";
		/**日期字体大小*/
		public static final String DATE_SZ = "dateSz";
		/**日期x方向起始位置*/
		public static final String DATE_X = "dX";
		/**日期y方向起始位置*/
		public static final String DATE_Y = "dY";
		
		/**
		 * 创建语句
		 * @return
		 */
		public static String createSQL() {
			StringBuilder sb = new StringBuilder();
			sb.append("CREATE TABLE " + T_NAME + " (")
              .append(_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, ")
              .append(PKGNAME + " TEXT,")
              .append(NAME + " TEXT,")
              .append(STATUS + " INTEGER DEFAULT 0,")
              .append(LOCK_TYPE + " INTEGER,")
              .append(DIRECT + " INTEGER,")
              .append(HINT + " TEXT DEFAULT '',")
              .append(TIME_COLOR + " TEXT,")
              .append(TIME_SZ + " INTEGER,")
              .append(TIME_X + " INTEGER,")
              .append(TIME_Y + " INTEGER,")
              .append(DATE_COLOR + " TEXT,")
              .append(DATE_SZ + " INTEGER,")
              .append(DATE_X + " INTEGER,")
              .append(DATE_Y + " INTEGER")
              .append(')');
			
			String str = sb.toString();
			sb = null;
			return str;
		}
		/**
		 * 删除表语句
		 * @return
		 */
		public static String dropSQL() {
			return "DROP TABLE IF EXISTS " + T_NAME;
		}
	}
    /***
	 * 桌面壁纸表
	 * @author fanjunchen
	 *
	 */
	public static class WallpaperImg {
		public static final Uri CONTENT_URI = Uri.withAppendedPath(AUTHORITY_URI, "wallpaper");
		/**获取当前使用的主题包*/
		public static final Uri CONTENT_USED_URI = Uri.withAppendedPath(AUTHORITY_URI, "wallpaperUsed");
		/**表名*/
		public static final String T_NAME = "wallpaper";
		/**包名，若没有包名则就是网络的*/
		public static final String PKGNAME = "pkgName";
		/**名称*/
		public static final String NAME = "_name";
		/**主题ID*/
		public static final String THEME_ID = "themeId";
		/**状态  0未下载， 1 下载中， 2已下载，3使用中*/
		public static final String STATUS = "status";
		/**锁屏缩略图名称或URL*/
		public static final String THUMB = "_thumb";
		/**锁屏原图名称或URL*/
		public static final String RAWIMG = "rawImg";
		/**
		 * 创建语句
		 * @return
		 */
		public static String createSQL() {
			StringBuilder sb = new StringBuilder();
			sb.append("CREATE TABLE " + T_NAME + " (")
              .append(_ID + " INTEGER PRIMARY KEY AUTOINCREMENT, ")
              .append(PKGNAME + " TEXT,")
              .append(NAME + " TEXT,")
              .append(THEME_ID + " INTEGER,")
              .append(STATUS + " INTEGER DEFAULT 0,")
              .append(THUMB + " TEXT,")
              .append(RAWIMG + " TEXT")
              .append(')');
			
			String str = sb.toString();
			sb = null;
			return str;
		}
		/**
		 * 删除表语句
		 * @return
		 */
		public static String dropSQL() {
			return "DROP TABLE IF EXISTS " + T_NAME;
		}
	}
	
	/*** 锁屏表Provider查询时返回的列     */
    public static final String[] WallProjection = {
        _ID,
        WallpaperImg.PKGNAME,
        WallpaperImg.NAME,
        WallpaperImg.STATUS,
        WallpaperImg.THEME_ID,
        WallpaperImg.THUMB,
        WallpaperImg.RAWIMG
	};
}
